@@ -26,7 +26,7 @@ from django_comments.views.utils import next_redirect, confirmation_view
 from django_comments_xtd import (
     comment_was_posted, comment_will_be_posted,
     get_form, get_model as get_comment_model,
-    signals, signed  #  module.
+    signals, signed
 )
 from django_comments_xtd.conf import settings
 from django_comments_xtd.models import (
@@ -286,7 +286,7 @@ def notify_comment_followers(comment):
         mute_url = reverse('comments-xtd-mute', args=[key.decode('utf-8')])
         message_context = {'user_name': name,
                            'comment': comment,
-                           # 'content_object': target,
+                           'content_object': comment.content_object,
                            'mute_url': mute_url,
                            'site': comment.site}
         text_message = text_message_template.render(message_context)
